import { JsonFile, Project, Task } from "projen";
import { JavaProject } from "projen/lib/java";
import { NodePackageManager } from "projen/lib/javascript";
import { PythonProject } from "projen/lib/python";
import { TypeScriptProject, TypeScriptProjectOptions } from "projen/lib/typescript";
import { Nx } from "./nx-types";
import { SyncpackConfig } from "./syncpack-options";
/**
 * Execute download/execute command to run based on package manager configured.
 *
 * @param packageManager package manager being used.
 * @param args args to append.
 */
export declare function buildDownloadExecutableCommand(packageManager: NodePackageManager, ...args: string[]): string;
/**
 * Execute command to run based on package manager configured.
 *
 * @param packageManager package manager being used.
 * @param args args to append.
 */
export declare function buildExecutableCommand(packageManager: NodePackageManager, ...args: string[]): string;
/**
 * Workspace configurations.
 *
 * @see https://classic.yarnpkg.com/lang/en/docs/workspaces/
 */
export interface WorkspaceConfig {
    /**
     * List of package globs to exclude from hoisting in the workspace.
     *
     * @see https://classic.yarnpkg.com/blog/2018/02/15/nohoist/
     */
    readonly noHoist?: string[];
    /**
     * Disable automatically applying `noHoist` logic for all sub-project "bundledDependencies".
     *
     * @default false
     */
    readonly disableNoHoistBundled?: boolean;
    /**
     * Links all local workspace project bins so they can be used for local development.
     *
     * Package bins are only linked when installed from the registry, however it is very useful
     * for monorepo development to also utilize these bin scripts. When enabled, this flag will
     * recursively link all bins from packages.json files to the root node_modules/.bin.
     */
    readonly linkLocalWorkspaceBins?: boolean;
    /**
     * List of additional package globs to include in the workspace.
     *
     * All packages which are parented by the monorepo are automatically added to the workspace, but you can use this
     * property to specify any additional paths to packages which may not be managed by projen.
     */
    readonly additionalPackages?: string[];
}
/**
 * Configuration for Monorepo Upgrade Deps task.
 */
export interface MonorepoUpgradeDepsOptions {
    /**
     * Name of the task to create.
     *
     * @default upgrade-deps
     */
    readonly taskName?: string;
    /**
     * Syncpack configuration.
     *
     * No merging is performed and as such a complete syncpackConfig is required if supplied.
     *
     * @default SyncpackConfig.DEFAULT_CONFIG
     */
    readonly syncpackConfig?: SyncpackConfig;
}
/**
 * Configuration options for the NxMonorepoProject.
 */
export interface NxMonorepoProjectOptions extends TypeScriptProjectOptions {
    /**
     * Configuration for NX.
     */
    readonly nxConfig?: Nx.WorkspaceConfig;
    /**
     * Configuration for workspace.
     */
    readonly workspaceConfig?: WorkspaceConfig;
    /**
     * Whether to include an upgrade-deps task at the root of the monorepo which will upgrade all dependencies.
     *
     * @default true
     */
    readonly monorepoUpgradeDeps?: boolean;
    /**
     * Monorepo Upgrade Deps options.
     *
     * This is only used if monorepoUpgradeDeps is true.
     *
     * @default undefined
     */
    readonly monorepoUpgradeDepsOptions?: MonorepoUpgradeDepsOptions;
}
/**
 *
 * @see https://nx.dev/packages/nx/documents/run-many#options
 */
export interface NxRunManyOptions {
    /** Task to run for affected projects */
    readonly target: string;
    /** This is the configuration to use when performing tasks on projects */
    readonly configuration?: string;
    /** Exclude certain projects from being processed */
    readonly exclude?: string;
    /**
     * Do not stop command execution after the first failed task.
     */
    readonly noBail?: boolean;
    /**
     * Defines how Nx emits outputs tasks logs
     * @default "stream"
     */
    readonly outputStyle?: "dynamic" | "static" | "stream" | "stream-without-prefixes";
    /**
     * Max number of parallel processes
     * @default 3
     */
    readonly parallel?: number;
    /** Project to run as list project names and/or patterns. */
    readonly projects?: string[];
    /** This is the name of the tasks runner configuration in nx.json */
    readonly runner?: string;
    /** Rerun the tasks even when the results are available in the cache. */
    readonly skipCache?: boolean;
    /** Ignore cycles in the task graph */
    readonly ignoreCycles?: boolean;
    /** Prints additional information about the commands (e.g. stack traces). */
    readonly verbose?: boolean;
}
/**
 * Options for overriding nx build tasks
 * @internal
 */
interface OverrideNxBuildTaskOptions {
    /**
     * Force unlocking task (eg: build task is locked)
     */
    readonly force?: boolean;
    /**
     * Disable further resets of the task by other components in further lifecycle stages
     * (eg eslint resets during preSynthesize)
     */
    readonly disableReset?: boolean;
}
/**
 * This project type will bootstrap a NX based monorepo with support for polygot
 * builds, build caching, dependency graph visualization and much more.
 *
 * @pjid nx-monorepo
 */
export declare class NxMonorepoProject extends TypeScriptProject {
    private readonly nxConfig?;
    private readonly workspaceConfig?;
    private readonly workspacePackages;
    readonly nxJson: JsonFile;
    private readonly _options;
    constructor(options: NxMonorepoProjectOptions);
    /**
     * Ensure NXProject is added when adding subprojects to the monorepo.
     *
     * @internal
     * @param subproject project to add.
     */
    _addSubProject(subproject: Project): void;
    /**
     * Helper to format `npx nx run-many ...` style command.
     * @param options
     */
    formatNxRunManyCommand(options: NxRunManyOptions): string;
    /**
     * Overrides "build" related project tasks (build, compile, test, etc.) with `npx nx run-many` format.
     * @param task - The task or task name to override
     * @param options - Nx run-many options
     * @param overrideOptions - Options for overriding the task
     * @returns - The task that was overridden
     * @internal
     */
    protected _overrideNxBuildTask(task: Task | string | undefined, options: NxRunManyOptions, overrideOptions?: OverrideNxBuildTaskOptions): Task | undefined;
    /**
     * Add project task that executes `npx nx run-many ...` style command.
     */
    addNxRunManyTask(name: string, options: NxRunManyOptions): Task;
    /**
     * Create an implicit dependency between two Projects. This is typically
     * used in polygot repos where a Typescript project wants a build dependency
     * on a Python project as an example.
     *
     * @param dependent project you want to have the dependency.
     * @param dependee project you wish to depend on.
     * @throws error if this is called on a dependent which does not have a NXProject component attached.
     */
    addImplicitDependency(dependent: Project, dependee: Project | string): void;
    /**
     * Adds a dependency between two Java Projects in the monorepo.
     * @param dependent project you want to have the dependency
     * @param dependee project you wish to depend on
     */
    addJavaDependency(dependent: JavaProject, dependee: JavaProject): void;
    /**
     * Adds a dependency between two Python Projects in the monorepo. The dependent must have Poetry enabled.
     * @param dependent project you want to have the dependency (must be a Poetry Python Project)
     * @param dependee project you wish to depend on
     * @throws error if the dependent does not have Poetry enabled
     */
    addPythonPoetryDependency(dependent: PythonProject, dependee: PythonProject): void;
    /**
     * Add one or more additional package globs to the workspace.
     * @param packageGlobs paths to the package to include in the workspace (for example packages/my-package)
     */
    addWorkspacePackages(...packageGlobs: string[]): void;
    private get instantiationOrderSubProjects();
    get subProjects(): Project[];
    /**
     * Create symbolic links to all local workspace bins. This enables the usage of bins the same
     * way as consumers of the packages have when installing from the registry.
     */
    protected linkLocalWorkspaceBins(): void;
    preSynthesize(): void;
    /**
     * @inheritDoc
     */
    synth(): void;
    /**
     * Ensures subprojects don't have a default task and that all packages use the same package manager.
     */
    private validateSubProjects;
    /**
     * Add a submodule entry to the appropriate workspace file.
     */
    private updateWorkspace;
    /**
     * Ensures the install task for non-node projects is executed postinstall.
     *
     * @private
     */
    private installNonNodeDependencies;
}
export {};
